@@ -53,13 +53,13 @@ class Domoticz(IPlugin):
 	
 	def switchlight(self, jsonInput):
 		
-		if jsonInput['outcome']['entities']['wit/location']['value'] :
-			location = jsonInput['outcome']['entities']['wit/location']['value']
+		if jsonInput['outcome']['entities']['location']['body']['value'] :
+			location = jsonInput['outcome']['entities']['location']['body']['value']
 		else:
 			bod = "pas de lieu"
 
-		if jsonInput['outcome']['entities']['wit/on_off']['value'] :
-			on_off = jsonInput['outcome']['entities']['wit/on_off']['value']
+		if jsonInput['outcome']['entities']['location']['body']['value'] :
+			on_off = jsonInput['outcome']['entities']['location']['body']['value']
 		else:
 			bod = "pas de on/off"
 #
